Coverage for /Users/marco/Code/django-rosetta/rosetta/signals: 100.00%

# Coverage for /Users/marco/Code/django-rosetta/rosetta/signals : 100.00%

## 3 statements 3 run 0 missing 0 excluded 0 partial

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 | from django import dispatch entry_changed = dispatch.Signal( providing_args=["user", "old_msgstr", "old_fuzzy", "pofile", "language_code",] ) post_save = dispatch.Signal( providing_args=["language_code","request",] )